﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using NPersistence;
using NPersistence.Ext;

namespace NPAExample
{
    [Entity]
    [Table(Name = "Emp_tbl")]
    public class Employee
    {
        [Id]
        [GeneratedValue]
        public virtual int id { get; set; }

        [Basic(Fetch = FetchType.LAZY, Optional = true)]
        [Column(Name = "empName", Nullable = false)]
        [Index(Name = "inx1")]
        [Unique(Name = "uq1")]
        public virtual string name { get; set; }

        public virtual DateTime birthDate { get; set; }

        public virtual string nickName { get; set; }

        [ManyToOne(Optional = true, Cascade = new CascadeType[] { CascadeType.ALL })]
        [JoinColumn(Name = "comp")]
        public virtual Company company { get; set; }

        public virtual string SayHello()
        {
            return string.Format("'Hello World!', said {0}, nickname: {1}, birthday:{2}, company{3}.", name, nickName, birthDate, company.name);
        }
    }

    [Entity]
    [Table(Name = "Comp_tbl")]
    public class Company
    {
        [Id]
        [GeneratedValue]
        public virtual int id { get; set; }

        [Unique(Name = "uq1")]
        public virtual string name { get; set; }

        [Embedded]
        public virtual Address address { get; set; }

        [OneToMany(TargetEntity = typeof(Employee), MappedBy = "company", Fetch = FetchType.LAZY, Cascade = new CascadeType[] { CascadeType.ALL })]
        [OrderColumn(Name = "listJoinCol")]
        public virtual System.Collections.IList employeeList { get; set; }

        public virtual string SayHello()
        {
            return string.Format("'Hello World!', said {0}, address:{1}.", name, address.SayHello());
        }
    }

    [Embeddable]
    public class Address
    {
        [Column(Name = "addCity")]
        public virtual String city { get; set; }
        public virtual String street { get; set; }
        public virtual int number { get; set; }

        public virtual string SayHello()
        {
            return string.Format("city:{0}, street:{1}, number:{2}.", city, street, number);
        }
    }
}
